Tool Bar (toolbar) — Orange Canvas Core 0.0.9 documentation

# Orange Canvas Core 0.0.9 documentation

## Tool Bar (toolbar)

# Tool Bar (`toolbar`)

A custom toolbar with linear uniform size layout.

class `orangecanvas.gui.toolbar.` `DynamicResizeToolBar`(parent=None, *args, **kwargs)

  Bases: `PyQt5.QtWidgets.QToolBar`

  A `QToolBar` subclass that dynamically resizes its tool buttons to fit available space (this is done by setting fixed size on the button instances).

  Note

  the class does not support QWidgetAction, separators, etc.